'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var acorn = require('acorn');
var MagicString = _interopDefault(require('magic-string'));

function ramda ( options ) {
    if ( !options ) options = {}

    if ( !options.transforms ) options.transforms = {}
    options.transforms.modules = false

    var sourceMap = options.sourceMap !== false

    return {
        name: 'ramda',

        transform: function transform(code, id){
            var ast;

            try {
                ast = acorn.parse( code, {
                    ecmaVersion: 6,
                    sourceType: 'module'
                })
            } catch ( err ) {
                err.message += " in " + id
                throw err;
            }

            var magicString = new MagicString( code )

            ast.body.forEach( function (node) {
                if ( node.type === 'ImportDeclaration' ) {
                    if(node.source.value === 'ramda'){
                        var imports = []
                        node.specifiers.forEach( function (specifier) {
                            if(specifier.imported != null) {
                                imports[specifier.imported.name] = specifier.local.name;
                            }
                        });

                        if ( sourceMap ) {
                            magicString.addSourcemapLocation( node.start );
                            magicString.addSourcemapLocation( node.end );
                        }

                        var importStatements = Object.keys(imports).map(
                            function (imported) { return ("import " + (imports[imported]) + " from 'ramda/src/" + imported + "';"); }
                        ).join('\n')

                        magicString.overwrite(
                            node.start,
                            node.end,
                            importStatements
                        )
                    }
                }
            })

            return {
                code: magicString.toString(),
                map: sourceMap ? magicString.generateMap() : null
            }
        }
    }
}

module.exports = ramda;